﻿using System;

namespace WpfGeoTagger.Models
{
	/// <summary>
	/// マップが変更された時のイベント データを格納します。
	/// </summary>
	public sealed class MapChangedEventArgs : EventArgs
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="action">マップに対して行われた操作。</param>
		/// <param name="latitude">緯度。</param>
		/// <param name="longitude">経度。</param>
		public MapChangedEventArgs( MapAction action, double latitude, double longitude )
		{
			this.Action    = action;
			this.Latitude  = latitude;
			this.Longitude = longitude;
		}

		/// <summary>
		/// マップに対して行われた操作を示す値を取得します。
		/// </summary>
		public MapAction Action { get; private set; }
		
		/// <summary>
		/// 緯度を取得します。
		/// </summary>
		public double Latitude { get; private set; }

		/// <summary>
		/// 経度を取得します。
		/// </summary>
		public double Longitude { get; private set; }
	}

	/// <summary>
	/// マップに対して行われた操作を表します。
	/// </summary>
	public enum MapAction
	{
		/// <summary>
		/// 移動。
		/// </summary>
		Moved
	}
}
