﻿using System;

namespace WpfGeoTagger.Models
{
	/// <summary>
	/// マーカーが変更された時のイベント データを格納します。
	/// </summary>
	public sealed class MarkerChangedEventArgs : EventArgs
	{
		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="action">マーカーに対して行われた操作。</param>
		/// <param name="id">マーカーの識別子。</param>
		public MarkerChangedEventArgs( MarkerAction action, int id )
			: this( action, id, 0.0, 0.0 )
		{
		}

		/// <summary>
		/// インスタンスを初期化します。
		/// </summary>
		/// <param name="action">マーカーに対して行われた操作。</param>
		/// <param name="id">マーカーの識別子。</param>
		/// <param name="latitude">緯度。</param>
		/// <param name="longitude">経度。</param>
		public MarkerChangedEventArgs( MarkerAction action, int id, double latitude, double longitude )
		{
			this.Action    = action;
			this.Id        = id;
			this.Latitude  = latitude;
			this.Longitude = longitude;
		}

		/// <summary>
		/// マーカーに対して行われた操作を示す値を取得します。
		/// </summary>
		public MarkerAction Action { get; private set; }

		/// <summary>
		/// マーカーの識別子を取得します。
		/// </summary>
		public int Id { get; private set; }

		/// <summary>
		/// 緯度を取得します。
		/// </summary>
		public double Latitude { get; private set; }

		/// <summary>
		/// 経度を取得します。
		/// </summary>
		public double Longitude { get; private set; }
	}

	/// <summary>
	/// マーカーに対して行われた操作を表します。
	/// </summary>
	public enum MarkerAction
	{
		/// <summary>
		/// 追加。
		/// </summary>
		Added,

		/// <summary>
		/// 移動。
		/// </summary>
		Moved,

		/// <summary>
		/// 削除。
		/// </summary>
		Removed,

		/// <summary>
		/// 選択。
		/// </summary>
		Selected
	}
}
